@@ -90,10 +90,9 @@ Mojo - Duct tape for the HTML5 web!
 
 =head1 DESCRIPTION
 
-Mojo provides a flexible runtime environment for Perl real-time web
-frameworks. It provides all the basic tools and helpers needed to write
-simple web applications and higher level web frameworks, such as
-L<Mojolicious>.
+A flexible runtime environment for Perl real-time web frameworks, with all the
+basic tools and helpers needed to write simple web applications and higher
+level web frameworks, such as L<Mojolicious>.
 
 See L<Mojolicious::Guides> for more!
 
