@@ -592,15 +592,17 @@ uploads and C<GET>/C<POST> parameters, in that order. Note that this method is
 context sensitive in some cases and therefore needs to be used with care,
 there can always be multiple values, which might have unexpected consequences.
 Parts of the request body need to be loaded into memory to parse C<POST>
-parameters, so you have to make sure it is not excessively large.
+parameters, so you have to make sure it is not excessively large, there's a
+10MB limit by default.
 
-  # List context is ambiguous and should be avoided
+  # List context is ambiguous and should be avoided, you can get multiple
+  # values returned for a query string like "?foo=bar&foo=baz&foo=yada"
   my $hash = {foo => $self->param('foo')};
 
   # Better enforce scalar context
   my $hash = {foo => scalar $self->param('foo')};
 
-  # The multi name form can also enforce scalar context
+  # The multi-name form can also be used to enforce scalar context
   my $hash = {foo => $self->param(['foo'])};
 
 For more control you can also access request information directly.
@@ -926,7 +928,7 @@ to inherit query parameters from the current request.
 Get L<Mojolicious::Validator::Validation> object for current request to
 validate C<GET>/C<POST> parameters. Parts of the request body need to be
 loaded into memory to parse C<POST> parameters, so you have to make sure it is
-not excessively large.
+not excessively large, there's a 10MB limit by default.
 
   my $validation = $c->validation;
   $validation->required('title')->size(3, 50);
@@ -996,8 +998,9 @@ You can call L</"finish"> at any time to end the stream.
 =head1 AUTOLOAD
 
 In addition to the L</"ATTRIBUTES"> and L</"METHODS"> above you can also call
-helpers on L<Mojolicious::Controller> objects. This includes all helpers from
-L<Mojolicious::Plugin::DefaultHelpers> and L<Mojolicious::Plugin::TagHelpers>.
+helpers provided by L</"app"> on L<Mojolicious::Controller> objects. This
+includes all helpers from L<Mojolicious::Plugin::DefaultHelpers> and
+L<Mojolicious::Plugin::TagHelpers>.
 
   $c->layout('green');
   $c->title('Welcome!');
